scheme_t* scheme_new(void);
scheme_t* scheme_create_default(void);
void scheme_destroy(scheme_t* scheme);
scheme_t* scheme_load(char* name);
void scheme_save(scheme_t* scheme);
void scheme_delete(char* name);
int scheme_is_valid(char* name);
void scheme_update_list(char* current);
void scheme_draw(scheme_t* scheme);
void scheme_load_global(char* scheme, int force);

style_t* style_new(char* name, char* fore, char* back, char* font);
void style_destroy(style_t* style);
style_t* style_search(scheme_t* scheme, char* name);
style_t* style_get(scheme_t* scheme, char* name);
void style_update(scheme_t* scheme,
		  char* name, char* fore, char* back, char* font);

void text_print_colored(GtkWidget* widget, scheme_t* scheme,
			char* base_color, char *text);
